<?php

/**
 * @file
 * Contains Drupal\search_api_page\SearchApiPageInterface.
 */

namespace Drupal\search_api_page;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface for defining Search page entities.
 */
interface SearchApiPageInterface extends ConfigEntityInterface {

  /**
   * Return the path.
   *
   * @return string
   */
  public function getPath();

  /**
   * Return the clean URL configuration.
   */
  public function getCleanUrl();

  /**
   * Return the path.
   *
   * @return string
   */
  public function getIndex();

  /**
   * Return the limit per page.
   *
   * @return int
   */
  public function getLimit();

  /**
   * Return the searched fields.
   *
   * @return array
   */
  public function getSearchedFields();

  /**
   * Retrieves a list of all available fulltext fields.
   *
   * @return string[]
   *   An options list of fulltext field identifiers mapped to their prefixed
   *   labels.
   */
  public function getFullTextFields();

  /**
   * Get the style to render the search results in.
   *
   * @return string
   */
  public function getStyle();

  /**
   * Get the view mode configuration per entity for rendering.
   *
   * @return string[]
   */
  public function getViewModeConfiguration();

  /**
   * Whether to render the results as view modes.
   *
   * @return bool
   */
  public function renderAsViewModes();

  /**
   * Whether to render the results as snippets.
   *
   * @return bool
   */
  public function renderAsSnippets();

  /**
   * Whether to show the search form above the search results.
   *
   * @return bool
   */
  public function showSearchForm();

  /**
   * Show all results when no search is performed.
   *
   * @return bool
   */
  public function showAllResultsWhenNoSearchIsPerformed();

}
